<?php

class Model
{
	protected string $table_name = '';
	protected array $original_data = [];
	protected array $changes = [];

	public function __construct(array $data)
	{
		$this->original_data = $data;
		$this->changes = [];
	}

	public function __get(string $key): mixed
	{
		return array_key_exists($key, $this->changes) ? $this->changes[$key] : $this->original_data[$key] ?? false;
	}

	public function __set(string $key, mixed $value): void
	{
		if (array_key_exists($key, $this->original_data)) $this->changes[$key] = $value;
	}

	public function save(): bool
	{
		if (empty($this->changes)) return true;

		$placeholders = [];
		$values = [];
		foreach ($this->changes as $key => $value) {
			$placeholders[] = "$key=?";
			$values[] = $value;
		}

		$values[] = $this->id;
		$query = 'UPDATE ' . $this->table_name . ' SET ' . implode(', ', $placeholders) . ' WHERE id = ?;';

		$result = db()->query($query, $values);
		return $result === false ? false : true;
	}
}
